@@ -21,7 +21,7 @@ class NatRule(ChildResource):
         'translated_source_port',
         'translated_destination_port',
     ]
-    SUPPORTED_PARAMS = ['']
+    SUPPORTED_PARAMS = []
     IGNORE_FOR_CREATE = []
     IGNORE_FOR_UPDATE = []
     MINIMUM_VERSION_REQUIRED_GET = '6.2.3'
@@ -29,7 +29,6 @@ class NatRule(ChildResource):
     @utils.support_params
     def get(
         self,
-        data: Union[dict, list],
         container_uuid=None,
         container_name=None,
         uuid=None,
